@@ -19,7 +19,6 @@ from string import Template
 import re
 import os
 import logging
-import platform
 import glob
 import shutil
 from collections import OrderedDict
@@ -62,16 +61,16 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 {'grub_directory_name': 'grub|grub2'}
         """
         self.custom_args = custom_args
-        arch = platform.machine()
+        arch = Defaults.get_platform_name()
         if arch == 'x86_64':
             # grub2 support for bios and efi systems
             self.arch = arch
         elif arch.startswith('ppc64'):
             # grub2 support for ofw and opal systems
             self.arch = arch
-        elif arch == 'i686' or arch == 'i586':
+        elif arch == 'ix86':
             # grub2 support for bios systems
-            self.arch = 'ix86'
+            self.arch = arch
         elif arch == 'aarch64' or arch.startswith('arm'):
             # grub2 support for efi systems
             self.arch = arch
@@ -85,11 +84,15 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         else:
             self.boot_directory_name = 'grub'
 
-        self.terminal = self.xml_state.build_type.get_bootloader_console() \
+        self.terminal = self.xml_state.get_build_type_bootloader_console() \
             or 'gfxterm'
         self.gfxmode = self.get_gfxmode('grub2')
         self.theme = self.get_boot_theme()
         self.timeout = self.get_boot_timeout_seconds()
+        self.timeout_style = \
+            self.xml_state.get_build_type_bootloader_timeout_style()
+        self.serial_line_setup = \
+            self.xml_state.get_build_type_bootloader_serial_line_setup()
         self.continue_on_timeout = self.get_continue_on_timeout()
         self.failsafe_boot = self.failsafe_boot_entry_requested()
         self.mediacheck_boot = self.xml_state.build_type.get_mediacheck()
@@ -323,6 +326,8 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             'gfxmode': self.gfxmode,
             'theme': self.theme,
             'boot_timeout': self.timeout,
+            'boot_timeout_style': self.timeout_style or 'menu',
+            'serial_line_setup': self.serial_line_setup or 'serial',
             'title': self.get_menu_entry_install_title(),
             'bootpath': self.get_boot_path('iso'),
             'boot_directory_name': self.boot_directory_name,
@@ -377,6 +382,8 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             'gfxmode': self.gfxmode,
             'theme': self.theme,
             'boot_timeout': self.timeout,
+            'boot_timeout_style': self.timeout_style or 'menu',
+            'serial_line_setup': self.serial_line_setup or 'serial',
             'title': self.get_menu_entry_title(plain=True),
             'bootpath': self.get_boot_path('iso'),
             'boot_directory_name': self.boot_directory_name,
@@ -565,6 +572,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         according to the root filesystem setup
 
         * GRUB_TIMEOUT
+        * GRUB_TIMEOUT_STYLE
         * SUSE_BTRFS_SNAPSHOT_BOOTING
         * GRUB_BACKGROUND
         * GRUB_THEME
@@ -580,18 +588,16 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             'GRUB_GFXMODE': self.gfxmode,
             'GRUB_TERMINAL': '"{0}"'.format(self.terminal)
         }
+        if self.timeout_style:
+            grub_default_entries['GRUB_TIMEOUT_STYLE'] = self.timeout_style
         if self.cmdline:
             grub_default_entries['GRUB_CMDLINE_LINUX_DEFAULT'] = '"{0}"'.format(
                 re.sub(r'root=.* |root=.*$', '', self.cmdline).strip()
             )
-        if self.terminal and 'serial' in self.terminal:
-            serial_format = '"serial {0} {1} {2} {3} {4}"'
-            grub_default_entries['GRUB_SERIAL_COMMAND'] = serial_format.format(
-                '--speed=38400',
-                '--unit=0',
-                '--word=8',
-                '--parity=no',
-                '--stop=1'
+        if self.terminal and 'serial' in self.terminal and \
+           self.serial_line_setup:
+            grub_default_entries['GRUB_SERIAL_COMMAND'] = '"{0}"'.format(
+                self.serial_line_setup
             )
         if self.theme:
             theme_setup = '{0}/{1}/theme.txt'
