@@ -93,6 +93,13 @@ class Defaults:
             '--threads=0'
         ]
 
+    @staticmethod
+    def get_platform_name():
+        arch = platform.machine()
+        if arch == 'i686' or arch == 'i586':
+            arch = 'ix86'
+        return arch
+
     @staticmethod
     def is_x86_arch(arch):
         """
@@ -104,7 +111,10 @@ class Defaults:
 
         :rtype: bool
         """
-        if arch == 'x86_64' or arch == 'i686' or arch == 'i586':
+        x86_arch_names = [
+            'x86_64', 'i686', 'i586', 'ix86'
+        ]
+        if arch in x86_arch_names:
             return True
         return False
 
@@ -348,6 +358,17 @@ class Defaults:
         """
         return 'auto'
 
+    @staticmethod
+    def get_default_bootloader():
+        """
+        Return default bootloader name which is grub2
+
+        :return: bootloader name
+
+        :rtype: str
+        """
+        return 'grub2'
+
     @staticmethod
     def get_grub_boot_directory_name(lookup_path):
         """
@@ -430,7 +451,7 @@ class Defaults:
 
         :rtype: list
         """
-        host_architecture = platform.machine()
+        host_architecture = Defaults.get_platform_name()
         modules = Defaults.get_grub_basic_modules(multiboot) + [
             'part_gpt',
             'part_msdos',
@@ -672,6 +693,7 @@ class Defaults:
         """
         return [
             '/usr/share/syslinux',
+            '/usr/lib/syslinux/bios',
             '/usr/lib/syslinux/modules/bios',
             '/usr/lib/ISOLINUX'
         ]
@@ -874,6 +896,7 @@ class Defaults:
             'x86_64': ['efi', 'uefi', 'bios', 'ec2hvm', 'ec2'],
             'i586': ['bios'],
             'i686': ['bios'],
+            'ix86': ['bios'],
             'aarch64': ['efi', 'uefi'],
             'arm64': ['efi', 'uefi'],
             'armv5el': ['efi', 'uefi'],
@@ -894,7 +917,7 @@ class Defaults:
         """
         Provides default firmware for specified architecture
 
-        :param string arch: platform.machine
+        :param string arch: machine architecture name
 
         :return: firmware name
 
@@ -904,6 +927,7 @@ class Defaults:
             'x86_64': 'bios',
             'i586': 'bios',
             'i686': 'bios',
+            'ix86': 'bios',
             'ppc': 'ofw',
             'ppc64': 'ofw',
             'ppc64le': 'ofw',
@@ -950,7 +974,7 @@ class Defaults:
         Provides architecture specific EFI directory name which
         stores the EFI binaries for the desired architecture.
 
-        :param string arch: platform.machine
+        :param string arch: machine architecture name
 
         :return: directory name
 
@@ -990,7 +1014,7 @@ class Defaults:
         """
         Provides architecture specific EFI boot binary name
 
-        :param string arch: platform.machine
+        :param string arch: machine architecture name
 
         :return: name
 
@@ -1138,25 +1162,25 @@ class Defaults:
         return '/etc/dracut.conf.d/02-kiwi.conf'
 
     @staticmethod
-    def get_live_dracut_module_from_flag(flag_name):
+    def get_live_dracut_modules_from_flag(flag_name):
         """
-        Provides flag_name to dracut module name map
+        Provides flag_name to dracut modules name map
 
         Depending on the value of the flag attribute in the KIWI image
-        description a specific dracut module needs to be selected
+        description specific dracut modules need to be selected
 
-        :return: dracut module name
+        :return: dracut module names as list
 
-        :rtype: str
+        :rtype: list
         """
         live_modules = {
-            'overlay': 'kiwi-live',
-            'dmsquash': 'dmsquash-live livenet'
+            'overlay': ['kiwi-live'],
+            'dmsquash': ['dmsquash-live', 'livenet']
         }
         if flag_name in live_modules:
             return live_modules[flag_name]
         else:
-            return 'kiwi-live'
+            return ['kiwi-live']
 
     @staticmethod
     def get_default_live_iso_root_filesystem():
@@ -1324,10 +1348,9 @@ class Defaults:
 
         :rtype: str
         """
-        arch = platform.machine()
-        if arch == 'i686' or arch == 'i586':
-            arch = 'ix86'
-        return os.sep.join(['boot', arch])
+        return os.sep.join(
+            ['boot', Defaults.get_platform_name()]
+        )
 
     @staticmethod
     def get_iso_tool_category():
@@ -1470,6 +1493,8 @@ class Defaults:
             return 'rpm'
         elif package_manager in deb_based:
             return 'dpkg'
+        elif package_manager == 'pacman':
+            return 'pacman'
 
     def get(self, key):
         """
